# TEST SCRIPT FOR SENDING PUSHOVER NOTIFICATIONS
#
# by jaydeel at ipcamtalk.com
# https://ipcamtalk.com/threads/send-pushover-notifications-with-pictures-and-hyperlinks.58819/
#
# REF: https://pushover.net/api

#Set-StrictMode  -Version 3

# ================================================
# USER SETTINGS...

# ENTER PUSHOVER API USER KEY
# ... https://pushover.net/
$po_user = "YOUR_API_USER_KEY"

# ENTER PUSHOVER API APPLICATION TOKEN
# ... TIP: consider adding a 'PowerShell' App to your https://pushover.net/ account
$po_token = "YOUR_API_APPLICATION_TOKEN"

# ENTER PUSHOVER MESSAGE PRIORITY
# ... (integer) -2|-1|0|1|2; -2=lowest, -1=low(silent), 0=normal, 1=high-priority, 2=emergency.
# ... see https://pushover.net/api#priority
$po_priority = 2

# ENTER PUSHOVER SOUND
# ... blank ("") is default sound
# ... see https://pushover.net/api#sounds
#$po_sound = "not-kiddin"  # custom sound
#$po_sound = "siren"  # built-in sound
$po_sound = ""  # default sound

# ENTER PUSHOVER DEVICE(S)
# ... blank ("") sends to all devices
# ... may be comma-delimited list.
# ... see https://pushover.net/api
#$po_device = 'galaxy-s21,iPhoneXS'  # multiple devices
#$po_device = 'galaxy-s21'  # single device
$po_device = ""  # all devices

# ENTER PUSHOVER RETRY PARAMETER (SECONDS)
# ... Required only for priority=2 messages (emergency)
# ... see https://pushover.net/api#priority
$po_retry = 30

# ENTER PUSHOVER EXPIRE PARAMETER (SECONDS)
# ... Required only for priority=2 messages (emergency)
# ... see https://pushover.net/api#priority
$po_expire = 300

# ENTER PUSHOVER NOTIFICATION CANCEL TAGS
# ... Used only by priority=2 messages (emergency)
# ... see https://pushover.net/api/receipts#cancel_by_tag
$po_tags = "a=BI"

# ===============================================

Write-Host "==========================================================="
Write-Host "Pushover Notification Test Utility"
Write-Host "-----------------------------------------------------------"

# BUILD MESSAGE
$hhmm = Get-Date -Format HH:mm:ss
$msg = "msg: Test message @$script:hhmm"
$msg = "$msg`nsound: $script:po_sound"
$msg = "$msg`ndevice(s): $script:po_device"
$msg = "$msg`npriority: $script:po_priority"
$msg = "$msg`nretry: $script:po_retry"
$msg = "$msg`nexpire: $script:po_expire"
$msg = "$msg`ntags: $script:po_tags"
Write-Host "msg = $msg"

# PUSH MESSAGE
$uri = 'https://api.pushover.net/1/messages.json'
$parameters = @{
	token    = $script:po_token
	user     = $script:po_user
	message  = $script:msg
	sound    = $script:po_sound
	device   = $script:po_device
	priority = $script:po_priority
	retry    = $script:po_retry
	expire   = $script:po_expire
	tags     = $script:po_tags
}
#$parameters | Invoke-RestMethod -Uri $uri -Method Post | Out-Null
$parameters | Invoke-RestMethod -Uri $uri -Method Post

Write-Host ""

